@@ -8,6 +8,7 @@ from .models import PlanAttr, HostAttr, DatabaseInfraAttr
 from base64 import b64encode
 import logging
 from integrations.storage.manager import StorageManager
+from dbaas_flipper.provider import FlipperProvider
 from django.template import Context, Template
 from time import sleep
 import paramiko
@@ -75,21 +76,8 @@ class CloudStackProvider(object):
                         LOG.warning("VirtualMachine destroyed!")
 
                         #removing data from flipper
-                        import re
-                        mp = (re.sub("[^a-zA-Z]","", database.databaseinfra.name)[:20])
-
-                        flipper_conn = MySQLdb.connect(host='dev.mysql.globoi.com', port=3306,
-                                                                            user='flipper', passwd='flipit!',
-                                                                            db='flipper_metadata')
-                        flipper_cursor = flipper_conn.cursor()
-                        
-                        sql_delete= "DELETE FROM masterpair  WHERE masterpair='%s' " % mp
-                        flipper_cursor.execute(sql_delete)
-
-                        sql_delete= "DELETE FROM node  WHERE masterpair='%s' " % mp
-                        flipper_cursor.execute(sql_delete)
-
-                        flipper_cursor.execute("commit")
+                        flipper = FlipperProvider()
+                        flipper.destroy_flipper_dependencies(name= database.databaseinfra.name[:20], environment= environment)
 
                         instance = Instance.objects.get(hostname=host)
                         
@@ -267,51 +255,16 @@ class CloudStackProvider(object):
         
         
         ##### cadastro metadados flipper
-        
-        flipper_conn = MySQLdb.connect(host='dev.mysql.globoi.com', port=3306,
-                                     user='flipper', passwd='flipit!',
-                                     db='flipper_metadata')
-        flipper_cursor = flipper_conn.cursor()
-        sql_insert = "INSERT INTO masterpair (masterpair, name, value) values ('%s', '%s', '%s')" % (masterpairname, 'broadcast', '10.25.12.255')
-        flipper_cursor.execute(sql_insert)
-        sql_insert = "INSERT INTO masterpair (masterpair, name, value) values ('%s', '%s', '%s')" % (masterpairname, 'mysql_password', 'flipit!')
-        flipper_cursor.execute(sql_insert)
-        sql_insert = "INSERT INTO masterpair (masterpair, name, value) values ('%s', '%s', '%s')" % (masterpairname, 'mysql_user', 'flipper')
-        flipper_cursor.execute(sql_insert)
-        sql_insert = "INSERT INTO masterpair (masterpair, name, value) values ('%s', '%s', '%s')" % (masterpairname, 'netmask', '255.255.255.0')
-        flipper_cursor.execute(sql_insert)
-        sql_insert = "INSERT INTO masterpair (masterpair, name, value) values ('%s', '%s', '%s')" % (masterpairname, 'quiesce_strategy', 'KillAll')
-        flipper_cursor.execute(sql_insert)
-        sql_insert = "INSERT INTO masterpair (masterpair, name, value) values ('%s', '%s', '%s')" % (masterpairname, 'read_ip', readip)
-        flipper_cursor.execute(sql_insert)
-        sql_insert = "INSERT INTO masterpair (masterpair, name, value) values ('%s', '%s', '%s')" % (masterpairname, 'send_arp_command', '/sbin/arping -I $sendarp_interface -c 5 -U -A $sendarp_ip')
-        flipper_cursor.execute(sql_insert)
-        sql_insert = "INSERT INTO masterpair (masterpair, name, value) values ('%s', '%s', '%s')" % (masterpairname, 'ssh_user', 'flipper')
-        flipper_cursor.execute(sql_insert)
-        sql_insert = "INSERT INTO masterpair (masterpair, name, value) values ('%s', '%s', '%s')" % (masterpairname, 'use_sudo', '1')
-        flipper_cursor.execute(sql_insert)
-        sql_insert = "INSERT INTO masterpair (masterpair, name, value) values ('%s', '%s', '%s')" % (masterpairname, 'write_ip', writeip)
-        flipper_cursor.execute(sql_insert)
-        
-        sql_insert = "INSERT INTO node (masterpair, node, name, value) values ('%s', '%s', '%s', '%s')" % (masterpairname, instance1.hostname.hostname, 'interface', 'eth2')
-        flipper_cursor.execute(sql_insert)
-        sql_insert = "INSERT INTO node (masterpair, node, name, value) values ('%s', '%s', '%s', '%s')" % (masterpairname, instance1.hostname.hostname, 'ip', instance1.hostname.hostname)
-        flipper_cursor.execute(sql_insert)
-        sql_insert = "INSERT INTO node (masterpair, node, name, value) values ('%s', '%s', '%s', '%s')" % (masterpairname, instance1.hostname.hostname, 'read_interface', 'eth2:98')
-        flipper_cursor.execute(sql_insert)
-        sql_insert = "INSERT INTO node (masterpair, node, name, value) values ('%s', '%s', '%s', '%s')" % (masterpairname, instance1.hostname.hostname, 'write_interface', 'eth2:99')
-        flipper_cursor.execute(sql_insert)
 
-        sql_insert = "INSERT INTO node (masterpair, node, name, value) values ('%s', '%s', '%s', '%s')" % (masterpairname, instance2.hostname.hostname, 'interface', 'eth2')
-        flipper_cursor.execute(sql_insert)
-        sql_insert = "INSERT INTO node (masterpair, node, name, value) values ('%s', '%s', '%s', '%s')" % (masterpairname, instance2.hostname.hostname, 'ip', instance2.hostname.hostname)
-        flipper_cursor.execute(sql_insert)
-        sql_insert = "INSERT INTO node (masterpair, node, name, value) values ('%s', '%s', '%s', '%s')" % (masterpairname, instance2.hostname.hostname, 'read_interface', 'eth2:98')
-        flipper_cursor.execute(sql_insert)
-        sql_insert = "INSERT INTO node (masterpair, node, name, value) values ('%s', '%s', '%s', '%s')" % (masterpairname, instance2.hostname.hostname, 'write_interface', 'eth2:99')
-        flipper_cursor.execute(sql_insert)
-        
-        flipper_cursor.execute("commit")
+
+
+        flipper = FlipperProvider()
+        flipper.create_flipper_dependencies(masterpairname= masterpairname, 
+                                                                readip= readip, 
+                                                                writeip= writeip, 
+                                                                instance1= instance1, 
+                                                                instance2= instance2, 
+                                                                environment= environment)
 
         
         run_scripts_vms(contextdict, instance1.hostname, 1, instance2.address )
